@@ -4,9 +4,6 @@
 python runtests.py -py
   Use py.test to run tests (more useful for debugging)
 
-python runtests.py -psyco
-  Enable psyco to make tests run about 50% faster
-
 python runtests.py -coverage
   Generate test coverage report. Statistics are written to /tmp
 
@@ -29,11 +26,6 @@ one of the arguments in their name are executed.
 
 import sys, os, traceback
 
-if "-psyco" in sys.argv:
-    sys.argv.remove('-psyco')
-    import psyco
-    psyco.full()
-
 profile = False
 if "-profile" in sys.argv:
     sys.argv.remove('-profile')
